@@ -9,17 +9,18 @@ from collections import namedtuple
 
 VersionInfo = namedtuple("VersionInfo", "major minor micro releaselevel serial")
 
-version_info = VersionInfo(major=0, minor=3, micro=0, releaselevel=".post", serial=0)
+version_info = VersionInfo(major=0, minor=3, micro=1, releaselevel=".post", serial=0)
 
 __title__ = "codingame"
 __author__ = "takos22"
-__version__ = "0.3.0.post0"
+__version__ = "0.3.1.post0"
 
 __all__ = [
     "Client",
     "CodinGamer",
     "ClashOfCode",
     "Player",
+    "Notification",
     "CodinGameAPIError",
     "CodinGamerNotFound",
     "ClashOfCodeNotFound",
@@ -28,4 +29,5 @@ __all__ = [
 from .client import Client
 from .codingamer import CodinGamer
 from .clash_of_code import ClashOfCode, Player
+from .notification import Notification
 from .exceptions import CodinGameAPIError, CodinGamerNotFound, ClashOfCodeNotFound
