@@ -10,3 +10,8 @@ class CodinGamerNotFound(CodinGameAPIError):
 class ClashOfCodeNotFound(CodinGameAPIError):
     """Raised when a Clash of Code isn't found."""
     pass
+
+class LoginRequired(CodinGameAPIError):
+    """Raised when an action requires the client to log in."""
+    def __init__(self, message=None):
+        super().__init__(message or "You must be logged in to perform this action.")
